module.exports = defineTest({
	description: 'treeshakes async functions (#492)'
});
